==> wowit-0.3.46.tar.gz: lib/Widget/filter_widget/component/search_screen.dart <==
import 'package:wowit/message.dart';
import 'package:flutter/material.dart';
import 'package:get/get.dart';

import '../filter_widget.dart';
import 'seached_list.dart';

class SearchScreen extends StatefulWidget {
  SearchScreen({
    this.loadData,
    this.title,
    this.filterItems,
    this.getOutsideSearchedResultItemView,
    Key key,
    this.getConditionView,
    this.fieldNameSearching,
    this.searchedListPadding,
    this.filterIcon,
  })  : assert(fieldNameSearching != null,
            'FitlerWidgetException: Need to provide fieldNameSearching'),
        super(key: key);

  final Widget Function(Map<String, Object> dataItem)
      getOutsideSearchedResultItemView;
  final Widget Function(
    Map<String, Object> mapCondition,
    void Function(String fieldName, Object value) onValueConditionChanged,
  ) getConditionView;
  final Future<Map<String, List<Map<String, Object>>>> Function() loadData;
  final String title;
  final List<FilterItem> filterItems;
  final String fieldNameSearching;
  final EdgeInsets searchedListPadding;
  final Widget filterIcon;

  @override
  _SearchScreenState createState() => _SearchScreenState();
}

class _SearchScreenState extends State<SearchScreen> {
  final ScrollController scrollController = ScrollController();
  final keywordController = TextEditingController();
  SearchedList wSearchedList;

  void searchHome(String query) {
    wSearchedList.search(query);
  }

  @override
  void initState() {
    final filterItems = <FilterItem>[];

    filterItems.addAll(widget.filterItems);
    filterItems.add(
      FilterItem(
          fieldName: widget.fieldNameSearching,
          filterMode: EFilterMode.insensitiveAndUnsignedContain),
    );

    wSearchedList = SearchedList(
      getOutSideConditionView: widget.getConditionView,
      scrollController: scrollController,
      filterItems: filterItems,
      getOutsideSearchedResultItemView: widget.getOutsideSearchedResultItemView,
      loadData: widget.loadData,
      title: widget.title,
      fieldNameSearching: widget.fieldNameSearching,
      searchedListPadding: widget.searchedListPadding,
    );

    scrollController.addListener(() {
      FocusScope.of(context).requestFocus(FocusNode());
    });
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    if (wSearchedList.getValueConditionByFieldName(widget.fieldNameSearching) ==
        null) {
      wSearchedList.search(keywordController.text);
    }
    return Scaffold(
      backgroundColor: Colors.white,
      appBar: _buildAppBar(context),
      body: wSearchedList,
    );
  }

  AppBar _buildAppBar(BuildContext context) {
    return AppBar(
      leading: IconButton(
        onPressed: () {
          FocusScope.of(context).requestFocus(FocusNode());
          Get.back();
        },
        icon: Icon(
          Icons.arrow_back_ios_outlined,
          color: Color(0xff2a367e),
        ),
        splashRadius: 24,
      ),
      elevation: 0.5,
      actions: [
        IconButton(
          onPressed: () {
            FocusScope.of(context).requestFocus(FocusNode());
            wSearchedList.goToFilterView();
          },
          icon: Icon(
            widget.filterIcon ?? Icons.filter_alt_outlined,
            color: Color(0xff2a367e),
          ),
          splashRadius: 24,
        ),
      ],
      title: TextField(
        autofocus: true,
        controller: keywordController,
        onChanged: searchHome,
        decoration: InputDecoration(
          border: InputBorder.none,
          hintText: Message.getMessage('HOME_Search_Tim_Kiem'),
        ),
      ),
      backgroundColor: Colors.white,
    );
  }
}

==> wowit-0.3.47.tar.gz: lib/Widget/filter_widget/component/search_screen.dart <==
import 'package:wowit/message.dart';
import 'package:flutter/material.dart';
import 'package:get/get.dart';

import '../filter_widget.dart';
import 'seached_list.dart';

class SearchScreen extends StatefulWidget {
  SearchScreen({
    this.loadData,
    this.title,
    this.filterItems,
    this.getOutsideSearchedResultItemView,
    Key key,
    this.getConditionView,
    this.fieldNameSearching,
    this.searchedListPadding,
    this.filterIcon,
  })  : assert(fieldNameSearching != null,
            'FitlerWidgetException: Need to provide fieldNameSearching'),
        super(key: key);

  final Widget Function(Map<String, Object> dataItem)
      getOutsideSearchedResultItemView;
  final Widget Function(
    Map<String, Object> mapCondition,
    void Function(String fieldName, Object value) onValueConditionChanged,
  ) getConditionView;
  final Future<Map<String, List<Map<String, Object>>>> Function() loadData;
  final String title;
  final List<FilterItem> filterItems;
  final String fieldNameSearching;
  final EdgeInsets searchedListPadding;
  final Widget filterIcon;

  @override
  _SearchScreenState createState() => _SearchScreenState();
}

class _SearchScreenState extends State<SearchScreen> {
  final ScrollController scrollController = ScrollController();
  final keywordController = TextEditingController();
  SearchedList wSearchedList;

  void searchHome(String query) {
    wSearchedList.search(query);
  }

  @override
  void initState() {
    final filterItems = <FilterItem>[];

    filterItems.addAll(widget.filterItems);
    filterItems.add(
      FilterItem(
          fieldName: widget.fieldNameSearching,
          filterMode: EFilterMode.insensitiveAndUnsignedContain),
    );

    wSearchedList = SearchedList(
      getOutSideConditionView: widget.getConditionView,
      scrollController: scrollController,
      filterItems: filterItems,
      getOutsideSearchedResultItemView: widget.getOutsideSearchedResultItemView,
      loadData: widget.loadData,
      title: widget.title,
      fieldNameSearching: widget.fieldNameSearching,
      searchedListPadding: widget.searchedListPadding,
    );

    scrollController.addListener(() {
      FocusScope.of(context).requestFocus(FocusNode());
    });
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    if (wSearchedList.getValueConditionByFieldName(widget.fieldNameSearching) ==
        null) {
      wSearchedList.search(keywordController.text);
    }
    return Scaffold(
      backgroundColor: Colors.white,
      appBar: _buildAppBar(context),
      body: wSearchedList,
    );
  }

  AppBar _buildAppBar(BuildContext context) {
    return AppBar(
      leading: IconButton(
        onPressed: () {
          FocusScope.of(context).requestFocus(FocusNode());
          Get.back();
        },
        icon: Icon(
          Icons.arrow_back_ios_outlined,
          color: Color(0xff2a367e),
        ),
        splashRadius: 24,
      ),
      elevation: 0.5,
      actions: [
        IconButton(
          onPressed: () {
            FocusScope.of(context).requestFocus(FocusNode());
            wSearchedList.goToFilterView();
          },
          icon: widget.filterIcon ??
              Icon(
                Icons.filter_alt_outlined,
                color: Color(0xff2a367e),
              ),
          splashRadius: 24,
        ),
      ],
      title: TextField(
        autofocus: true,
        controller: keywordController,
        onChanged: searchHome,
        decoration: InputDecoration(
          border: InputBorder.none,
          hintText: Message.getMessage('HOME_Search_Tim_Kiem'),
        ),
      ),
      backgroundColor: Colors.white,
    );
  }
}
